@@ -1,9 +1,16 @@
 # this function estimates ancestral traits with a trend
-# written by Liam J. Revell 2011
+# written by Liam J. Revell 2011/2013
 
 anc.trend<-function(phy,x,maxit=2000){
+
+	# preliminaries
+	# require dependencies
+	require(ape)
 	# set global
 	tol<-1e-8
+	# check to make sure that C will be non-singular
+	if(any(tree$edge.length<=(10*.Machine$double.eps)))
+		stop("some branch lengths are 0 or nearly zero")
 	# compute C
 	D<-dist.nodes(phy)
 	ntips<-length(phy$tip.label)
